@@ -150,7 +150,8 @@ def datetimes_to_durations( start_times, end_times, fill_date = None, freq='D',
     end_times_ = to_datetime(end_times, dayfirst=dayfirst, coerce=True)
 
     T = (end_times_ - start_times_).map(lambda x: x.astype(freq_string).astype(float) )
-
+    if (T < 0).sum():
+        print "Warning: some values of start_times are before end_times"
     return T.values, C.values
 
 def inv_normal_cdf(p):
@@ -183,12 +184,10 @@ def cross_validation(fitter, T, X, censorship=None, k=5, loss_function="median")
     This implements the censor-sensative loss function as given in 
     'Prediction Performance of Survival Models', Yan Yuan, 2008
     """
-
     pass
 
 def yaun_loss(fitter, T_true, T_pred, X_train, T_train, censorship=None):
-
-
+    "[WIP]"
     if censorship==None:
         t = T_pred.shape[0]
         sC = np.ones((t,1))
@@ -202,14 +201,15 @@ def yaun_loss(fitter, T_true, T_pred, X_train, T_train, censorship=None):
     return (censorship*(T_pred-T_true)**2/sC).mean()
 
 def quadrature(fx,x):
-  t = x.shape[0]
-  return (0.5*fx[:,0] + fx[:,1:-1].sum(1) + 0.5*fx[:,-1])*(x[-1] - x[0])*1.0/t
+    t = x.shape[0]
+    return (0.5*fx[:,0] + fx[:,1:-1].sum(1) + 0.5*fx[:,-1])*(x[-1] - x[0])*1.0/t
 
 def basis(n,i):
     x = np.zeros((n,1))
     x[i] = 1
     return x
 
-
-def kernel_smoother(timeline, hazards, sigma):
-    pass
+def epanechnikov_kernel(t, T, bandwidth=1.):
+    M = 0.75*(1-(t-T)/bandwidth)**2
+    M[ abs((t-T)) >= bandwidth] = 0
+    return M
